# 📦 Welcome to TStore

|                   |                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                             |
| ----------------- |   |
| Deployment        | [![PyPI](https://badge.fury.io/py/ts-store.svg?style=flat)](https://pypi.org/project/ts-store/) [![Conda](https://img.shields.io/conda/vn/conda-forge/ts-store.svg?logo=conda-forge&logoColor=white&style=flat)](https://anaconda.org/conda-forge/ts-store)                                                                                                                                                                                                                                                                                                                                                                                                                 |
| Activity          | [![PyPI Downloads](https://img.shields.io/pypi/dm/ts-store.svg?label=PyPI%20downloads&style=flat)](https://pypi.org/project/ts-store/) [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/ts-store.svg?label=Conda%20downloads&style=flat)](https://anaconda.org/conda-forge/ts-store)                                                                                                                                                                                                                                                                                                                                                                         |
| Python Versions   | [![Python Versions](https://img.shields.io/badge/Python-3.9%20%203.10%20%203.11%20%203.12-blue?style=flat)](https://www.python.org/downloads/)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                              |
| Supported Systems | [![Linux](https://img.shields.io/github/actions/workflow/status/ltelab/tstore/.github/workflows/tests.yml?label=Linux&style=flat)](https://github.com/ltelab/tstore/actions/workflows/tests.yml) [![macOS](https://img.shields.io/github/actions/workflow/status/ltelab/tstore/.github/workflows/tests.yml?label=macOS&style=flat)](https://github.com/ltelab/tstore/actions/workflows/tests.yml) [![Windows](https://img.shields.io/github/actions/workflow/status/ltelab/tstore/.github/workflows/tests_windows.yml?label=Windows&style=flat)](https://github.com/ltelab/tstore/actions/workflows/tests_windows.yml)                                                      |
| Project Status    | [![Project Status](https://www.repostatus.org/badges/latest/active.svg?style=flat)](https://www.repostatus.org/#active)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                     |
| Build Status      | [![Tests](https://github.com/ltelab/tstore/actions/workflows/tests.yml/badge.svg?style=flat)](https://github.com/ltelab/tstore/actions/workflows/tests.yml) [![Lint](https://github.com/ltelab/tstore/actions/workflows/lint.yml/badge.svg?style=flat)](https://github.com/ltelab/tstore/actions/workflows/lint.yml) [![Docs](https://readthedocs.org/projects/ts-store/badge/?version=latest&style=flat)](https://ts-store.readthedocs.io/en/latest/)                                                                                                                                                                                                                      |
| Linting           | [![Black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat)](https://github.com/psf/black) [![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json&style=flat)](https://github.com/astral-sh/ruff) [![Codespell](https://img.shields.io/badge/Codespell-enabled-brightgreen?style=flat)](https://github.com/codespell-project/codespell)                                                                                                                                                                                                                                               |
| Code Coverage     | [![Coveralls](https://coveralls.io/repos/github/ltelab/tstore/badge.svg?branch=main&style=flat)](https://coveralls.io/github/ltelab/tstore?branch=main) [![Codecov](https://codecov.io/gh/ltelab/tstore/branch/main/graph/badge.svg?style=flat)](https://codecov.io/gh/ltelab/tstore)                                                                                                                                                                                                                                                                                                                                                                                       |
| Code Quality      | [![Codefactor](https://www.codefactor.io/repository/github/ltelab/tstore/badge?style=flat)](https://www.codefactor.io/repository/github/ltelab/tstore) [![Codebeat](https://codebeat.co/badges/664f3ba2-a3b5-4a82-8e0c-7024063f210a?style=flat)](https://codebeat.co/projects/github-com-ltelab-tstore-main) [![Codacy](https://app.codacy.com/project/badge/Grade/7bcd3144d96c40cfac16d9cbd609770c?style=flat)](https://app.codacy.com/gh/ltelab/tstore/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade) [![Codescene](https://codescene.io/projects/41868/status-badges/code-health?style=flat)](https://codescene.io/projects/41868) |
| License           | [![License](https://img.shields.io/github/license/ltelab/tstore?style=flat)](https://github.com/ltelab/tstore/blob/main/LICENSE)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            |
| Community         | [![Slack](https://img.shields.io/badge/Slack-tstore-green.svg?logo=slack&style=flat)](https://join.slack.com/t/tstore-workspace/shared_invite/zt-2g8uanpgm-dYrL6rxk5pEpAKCYn~QQ5Q) [![GitHub Discussions](https://img.shields.io/badge/GitHub-Discussions-green?logo=github&style=flat)](https://github.com/ltelab/tstore/discussions)                                                                                                                                                                                                                                                                                                                                      |
| Citation          | [![DOI](https://zenodo.org/badge/286664485.svg?style=flat)](https://doi.org/10.5281/zenodo.7753488)                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         |

[**Slack**](https://join.slack.com/t/tstore-workspace/shared_invite/zt-2g8uanpgm-dYrL6rxk5pEpAKCYn~QQ5Q) | [**Docs**](https://ts-store.readthedocs.io/en/latest/)

## 🚀 Quick start

Flexible storage for time series

TODO

______________________________________________________________________

#### 📖 Explore the TStore documentation

To discover all TStore download, manipulation, analysis and plotting utilities, or how to contribute your custom retrieval to TStore:

- please read the software documentation available at [https://ts-store.readthedocs.io/en/latest/](https://ts-store.readthedocs.io/en/latest/).
- dive into the Jupyter Notebooks [Tutorials](https://github.com/ltelab/tstore/tree/main/tutorials).

## 🛠️ Installation

### conda

TStore can be installed via [conda][conda_link] on Linux, Mac, and Windows.
Install the package by typing the following command in the terminal:

```bash
conda install ts-store
```

In case conda-forge is not set up for your system yet, see the easy to follow instructions on [conda-forge][conda_forge_link].

### pip

TStore can be installed also via [pip][pip_link] on Linux, Mac, and Windows.
On Windows you can install [WinPython][winpy_link] to get Python and pip running.

Install the TStore package by typing the following command in the terminal:

```bash
pip install ts-store
```

To install the latest development version via pip, see the [documentation][dev_install_link].

## 💭 Feedback and Contributing Guidelines

If you aim to contribute your data or discuss the future development of TStore,
we highly suggest to join the [**TStore Slack Workspace**](https://join.slack.com/t/tstore-workspace/shared_invite/zt-2g8uanpgm-dYrL6rxk5pEpAKCYn~QQ5Q)

Feel free to also open a [GitHub Issue](https://github.com/ltelab/tstore/issues) or a [GitHub Discussion](https://github.com/ltelab/tstore/discussions) specific to your questions or ideas.

## Citation

If you are using TStore in your publication please cite our Zenodo repository:

> Ghiggi Gionata. ltelab/tstore. Zenodo. [![https://doi.org/10.5281/zenodo.7753488](https://zenodo.org/badge/286664485.svg?style=flat)](https://doi.org/10.5281/zenodo.7753488)

If you want to cite a specific software version, have a look at the [Zenodo site](https://doi.org/10.5281/zenodo.7753488).

## License

The content of this repository is released under the terms of the [MIT license](LICENSE).


# OUTDATED HERE BELOW

## Requirements

- [mamba](https://github.com/mamba-org/mamba), which can be installed using conda or [mambaforge](https://github.com/conda-forge/miniforge#mambaforge) (see [the official installation instructions](https://github.com/mamba-org/mamba#installation))
- [snakemake](https://snakemake.github.io), which can be installed using [conda or mamba](https://snakemake.readthedocs.io/en/stable/getting_started/installation.html)

## Instructions

1. Create a conda environment:

```bash
snakemake -c1 create_environment
```

2. Activate it (if using conda, replace `mamba` for `conda`):

```bash
mamba activate tstore
```

3. Register the IPython kernel for Jupyter:

```bash
snakemake -c1 register_ipykernel
```

4. Activate pre-commit for the git repository:

```bash
pre-commit install
pre-commit install --hook-type commit-msg
```

## Acknowledgments

- Based on the [cookiecutter-data-snake :snake:](https://github.com/martibosch/cookiecutter-data-snake) template for reproducible data science.

[conda_forge_link]: https://github.com/conda-forge/ts-store-feedstock#installing-ts-store
[conda_link]: https://docs.conda.io/en/latest/miniconda.html
[dev_install_link]: https://ts-store.readthedocs.io/en/latest/02_installation.html#installation-for-contributors
[pip_link]: https://pypi.org/project/ts-store
[winpy_link]: https://winpython.github.io/
